pub enum SourceOrigin {
Authored(Span),
Omitted,
}Expand description
Whether a semantic value was authored or supplied by a language default.
Variants
Authored(Span)
The value was written in source at this end-exclusive span.
Omitted
The value was omitted from source.
Implementations