pub struct SourceMap { /* private fields */ }Expand description
Deterministic source locations associated with normalized semantic identities.
Implementations
Sourceimpl SourceMap
impl SourceMap
Sourcepub const fn theme(&self) -> SourceOrigin
pub const fn theme(&self) -> SourceOrigin
Returns the authored diagram theme identifier or omitted default.
Sourcepub fn node_icons(&self) -> &[NodeIconSource]
pub fn node_icons(&self) -> &[NodeIconSource]
Returns node icon entries in depth-first declaration order.
Sourcepub fn node_icon(&self, node_id: &str) -> Option<SourceOrigin>
pub fn node_icon(&self, node_id: &str) -> Option<SourceOrigin>
Finds a node’s authored icon string or omitted default by node identifier.
Sourcepub fn layout_orders(&self) -> &[LayoutOrderSource]
pub fn layout_orders(&self) -> &[LayoutOrderSource]
Returns layout order entries with the diagram first, then groups in depth-first order.
Sourcepub fn diagram_order(&self) -> SourceOrigin
pub fn diagram_order(&self) -> SourceOrigin
Returns the diagram’s authored order statement or omitted value.
Sourcepub fn group_order(&self, group_id: &str) -> Option<SourceOrigin>
pub fn group_order(&self, group_id: &str) -> Option<SourceOrigin>
Finds a group’s authored order statement or omitted value by group identifier.