pub struct LosslessParseOutput {
pub document: Option<Document>,
pub diagnostics: Vec<Diagnostic>,
}Expand description
Output of syntactic parsing into the lossless source model.
Fields
document: Option<Document>Lossless document, present only when lexical and syntax parsing succeeds.
diagnostics: Vec<Diagnostic>Lexical and syntax diagnostics.